# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jobs/nbox_ws.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..jobs import job_pb2 as jobs_dot_job__pb2
from ..common import common_pb2 as common_dot_common__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12jobs/nbox_ws.proto\x12\x07jobs.ws\x1a\x0ejobs/job.proto\x1a\x13\x63ommon/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x7f\n\nJobRequest\x12&\n\tauth_info\x18\x01 \x01(\x0b\x32\x13.common.NBXAuthInfo\x12\x16\n\x03job\x18\x02 \x01(\x0b\x32\t.jobs.Job\x12\x31\n\x10integration_data\x18\x03 \x01(\x0b\x32\x17.common.IntegrationData\"\xb6\x01\n\x10UpdateJobRequest\x12&\n\tauth_info\x18\x01 \x01(\x0b\x32\x13.common.NBXAuthInfo\x12\x16\n\x03job\x18\x02 \x01(\x0b\x32\t.jobs.Job\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x10integration_data\x18\x04 \x01(\x0b\x32\x17.common.IntegrationData\"\x8b\x01\n\x0fListJobsRequest\x12&\n\tauth_info\x18\x01 \x01(\x0b\x32\x13.common.NBXAuthInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x31\n\x10integration_data\x18\x04 \x01(\x0b\x32\x17.common.IntegrationData\">\n\x10ListJobsResponse\x12\x17\n\x04jobs\x18\x01 \x03(\x0b\x32\t.jobs.Job\x12\x11\n\tnext_page\x18\x02 \x01(\x05\"\xd5\x01\n\x10UpdateRunRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x16\n\x03job\x18\x02 \x01(\x0b\x32\t.jobs.Job\x12.\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x04 \x01(\t\x12&\n\tauth_info\x18\x05 \x01(\x0b\x32\x13.common.NBXAuthInfo\x12\x31\n\x10integration_data\x18\x06 \x01(\x0b\x32\x17.common.IntegrationData2\xcb\x04\n\x0cWSJobService\x12*\n\x06GetJob\x12\x13.jobs.ws.JobRequest\x1a\t.jobs.Job\"\x00\x12\x41\n\x08ListJobs\x12\x18.jobs.ws.ListJobsRequest\x1a\x19.jobs.ws.ListJobsResponse\"\x00\x12\x31\n\rUploadJobCode\x12\x13.jobs.ws.JobRequest\x1a\t.jobs.Job\"\x00\x12-\n\tCreateJob\x12\x13.jobs.ws.JobRequest\x1a\t.jobs.Job\"\x00\x12\x33\n\tUpdateJob\x12\x19.jobs.ws.UpdateJobRequest\x1a\t.jobs.Job\"\x00\x12:\n\tDeleteJob\x12\x13.jobs.ws.JobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x32\n\nGetJobLogs\x12\x13.jobs.ws.JobRequest\x1a\x0b.common.Log\"\x00\x30\x01\x12?\n\nTriggerJob\x12\x13.jobs.ws.JobRequest\x1a\x1a.google.protobuf.BoolValue\"\x00\x12@\n\tUpdateRun\x12\x19.jobs.ws.UpdateRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x42\n\x0bGetRunToken\x12\x13.jobs.ws.JobRequest\x1a\x1c.google.protobuf.StringValue\"\x00\x42=Z;github.com/NimbleBoxAI/jobs-architecture/jobs_pb/v3;jobs_pbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jobs.nbox_ws_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/NimbleBoxAI/jobs-architecture/jobs_pb/v3;jobs_pb'
  _JOBREQUEST._serialized_start=196
  _JOBREQUEST._serialized_end=323
  _UPDATEJOBREQUEST._serialized_start=326
  _UPDATEJOBREQUEST._serialized_end=508
  _LISTJOBSREQUEST._serialized_start=511
  _LISTJOBSREQUEST._serialized_end=650
  _LISTJOBSRESPONSE._serialized_start=652
  _LISTJOBSRESPONSE._serialized_end=714
  _UPDATERUNREQUEST._serialized_start=717
  _UPDATERUNREQUEST._serialized_end=930
  _WSJOBSERVICE._serialized_start=933
  _WSJOBSERVICE._serialized_end=1520
# @@protoc_insertion_point(module_scope)
