"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class HandshakeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    JWT_FIELD_NUMBER: builtins.int
    INSTANCEKEY_FIELD_NUMBER: builtins.int
    LAUNCHURL_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    jwt: typing.Text
    instanceKey: typing.Text
    launchURL: typing.Text
    port: typing.Text
    def __init__(self,
        *,
        jwt: typing.Text = ...,
        instanceKey: typing.Text = ...,
        launchURL: typing.Text = ...,
        port: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instanceKey",b"instanceKey","jwt",b"jwt","launchURL",b"launchURL","port",b"port"]) -> None: ...
global___HandshakeRequest = HandshakeRequest

class HandshakeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKEN_FIELD_NUMBER: builtins.int
    token: typing.Text
    def __init__(self,
        *,
        token: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token",b"token"]) -> None: ...
global___HandshakeResponse = HandshakeResponse

class DataPacket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKEN_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    token: typing.Text
    data: builtins.bytes
    def __init__(self,
        *,
        token: typing.Text = ...,
        data: builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data","token",b"token"]) -> None: ...
global___DataPacket = DataPacket
