# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lmao.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nlmao.proto\x12\x04lmao\x1a\x1fgoogle/protobuf/timestamp.proto\"i\n\tLogBuffer\x12\x13\n\x0b\x61gent_token\x18\x01 \x01(\t\x12\x1e\n\x08run_logs\x18\x02 \x03(\x0b\x32\x0c.lmao.RunLog\x12\'\n\tlive_logs\x18\x03 \x03(\x0b\x32\x14.lmao.ServingHTTPLog\"\x86\x01\n\x0eServingHTTPLog\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x13\n\x0bstatus_code\x18\x03 \x01(\x05\x12\x12\n\nlatency_ms\x18\x04 \x01(\x02\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"[\n\x16ListDeploymentsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x1a\n\x12serving_id_or_name\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\"\xc7\x01\n\x17ListDeploymentsResponse\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x36\n\x07serving\x18\x02 \x03(\x0b\x32%.lmao.ListDeploymentsResponse.Serving\x12\x13\n\x0btotal_pages\x18\x03 \x01(\x05\x1aI\n\x07Serving\x12\x12\n\nserving_id\x18\x01 \x01(\t\x12\x14\n\x0cserving_name\x18\x02 \x01(\t\x12\x14\n\x0ctotal_models\x18\x03 \x01(\x05\"q\n\x13ListServingsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x0f\n\x07page_no\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\x08\"`\n\x14ListServingsResponse\x12\x11\n\tmodel_ids\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x12\n\ncreated_at\x18\x03 \x03(\x03\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\"\xe8\x01\n\x07Serving\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12!\n\x05\x61gent\x18\x02 \x01(\x0b\x32\x12.lmao.AgentDetails\x12\x13\n\x0b\x61gent_token\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12$\n\x06status\x18\x06 \x01(\x0e\x32\x14.lmao.Serving.Status\x12\x12\n\nupdated_at\x18\x07 \x01(\x03\"1\n\x06Status\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCOMPLETED\x10\x02\"\xbd\x01\n\x06Record\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\nvalue_type\x18\x02 \x01(\x0e\x32\x15.lmao.Record.DataType\x12\x0c\n\x04step\x18\x03 \x01(\x03\x12\x12\n\nfloat_data\x18\x64 \x03(\x02\x12\x14\n\x0cinteger_data\x18\x65 \x03(\x05\x12\x13\n\x0bstring_data\x18\x66 \x03(\t\".\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\n\n\x06STRING\x10\x02\"\xff\x01\n\x0cRecordColumn\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\nvalue_type\x18\x02 \x01(\x0e\x32\x1b.lmao.RecordColumn.DataType\x12*\n\x04rows\x18\x03 \x03(\x0b\x32\x1c.lmao.RecordColumn.RecordRow\x1aU\n\tRecordRow\x12\t\n\x01x\x18\x01 \x01(\x03\x12\x12\n\nfloat_data\x18\x64 \x01(\x02\x12\x14\n\x0cinteger_data\x18\x65 \x01(\x05\x12\x13\n\x0bstring_data\x18\x66 \x01(\t\".\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\n\n\x06STRING\x10\x02\"\xe0\x01\n\x06RunLog\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x1a\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x0c.lmao.Record\x12\'\n\x0b\x63olumn_data\x18\x03 \x03(\x0b\x32\x12.lmao.RecordColumn\x12&\n\x08log_type\x18\x04 \x01(\x0e\x32\x14.lmao.RunLog.LogType\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x06 \x01(\t\"(\n\x07LogType\x12\n\n\x06SYSTEM\x10\x00\x12\x07\n\x03NBX\x10\x01\x12\x08\n\x04USER\x10\x02\"\xd7\x01\n\x0c\x41gentDetails\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12$\n\x04type\x18\x02 \x01(\x0e\x32\x16.lmao.AgentDetails.NBX\x12\x14\n\nnbx_job_id\x18\x65 \x01(\tH\x00\x12\x18\n\x0enbx_serving_id\x18\x66 \x01(\tH\x00\x12\x14\n\nnbx_run_id\x18g \x01(\tH\x01\x12\x16\n\x0cnbx_model_id\x18h \x01(\tH\x01\"\x1b\n\x03NBX\x12\x07\n\x03JOB\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x42\x04\n\x02idB\n\n\x08instance\"\x8b\x01\n\x0eInitRunRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12)\n\ragent_details\x18\x04 \x01(\x0b\x32\x12.lmao.AgentDetails\x12\x0e\n\x06\x63onfig\x18\x06 \x01(\t\"M\n\x04\x46ile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\x03\x12\x10\n\x08is_input\x18\x03 \x01(\x08\x12\x11\n\trelic_key\x18\x05 \x01(\t\"<\n\x08\x46ileList\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x19\n\x05\x66iles\x18\x02 \x03(\x0b\x32\n.lmao.File\"\x86\x03\n\x03Run\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x15\n\rexperiment_id\x18\x04 \x01(\t\x12!\n\x05\x61gent\x18\x05 \x01(\x0b\x32\x12.lmao.AgentDetails\x12\x12\n\ncreated_at\x18\x06 \x01(\x03\x12\x12\n\nupdated_at\x18\x07 \x01(\x03\x12\x10\n\x08\x65nded_at\x18\x08 \x01(\x03\x12\x15\n\rsave_location\x18\t \x01(\t\x12!\n\tfile_list\x18\n \x01(\x0b\x32\x0e.lmao.FileList\x12\x0e\n\x06\x63onfig\x18\x0b \x01(\t\x12 \n\x06status\x18\x0c \x01(\x0e\x32\x10.lmao.Run.Status\x12\x13\n\x0bupdate_keys\x18\x64 \x03(\t\"J\n\x06Status\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCOMPLETED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04\"X\n\x13ListProjectsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x1a\n\x12project_id_or_name\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\"\xb2\x01\n\x07Project\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x12\n\ntotal_runs\x18\x04 \x01(\x05\x12\x13\n\x0blog_metrics\x18\x05 \x03(\t\x12\x16\n\x0e\x63onfig_metrics\x18\x06 \x03(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x12\n\nis_deleted\x18\x08 \x01(\x08\"L\n\x14ListProjectsResponse\x12\x1f\n\x08projects\x18\x01 \x03(\x0b\x32\r.lmao.Project\x12\x13\n\x0btotal_pages\x18\x02 \x01(\x05\"q\n\x0fListRunsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0f\n\x07page_no\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\x08\"a\n\x10ListRunsResponse\x12\x16\n\x0e\x65xperiment_ids\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x12\n\ncreated_at\x18\x03 \x03(\x03\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\"\x7f\n\rRunLogRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x10\n\x08start_at\x18\x05 \x01(\x05\x12\x0e\n\x06\x65nd_at\x18\x06 \x01(\x05\"/\n\x0b\x41\x63knowledge\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x89\x01\n\x19GetExperimentTableRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\x12\x15\n\rexperiment_id\x18\x06 \x01(\t\x12\r\n\x05start\x18\x04 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x05\"\x8f\x01\n\x0f\x45xperimentTable\x12\x13\n\x0btotal_pages\x18\x01 \x01(\x05\x12\'\n\x04rows\x18\x02 \x03(\x0b\x32\x19.lmao.ExperimentTable.Row\x1a>\n\x03Row\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12 \n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x12.lmao.RecordColumn\"\x8f\x02\n\x04Rule\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x11\n\trule_name\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x16\n\x0eis_deactivated\x18\x05 \x01(\x08\x12\x12\n\nis_deleted\x18\x06 \x01(\x08\x12\r\n\x05logic\x18\x07 \x01(\t\x12\x11\n\temail_ids\x18\x08 \x03(\t\x12\x15\n\ralert_message\x18\t \x01(\t\x12\x12\n\ntrue_count\x18\n \x01(\x05\x12\x15\n\rlogic_version\x18\x0b \x01(\x05\x12\x11\n\tmax_range\x18\x0c \x01(\x05\x12\x13\n\x0bupdate_keys\x18\x64 \x03(\t\"\x89\x01\n\tListRules\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\x12\x19\n\x05rules\x18\x05 \x03(\x0b\x32\n.lmao.Rule\x12\x11\n\trule_name\x18\x06 \x01(\t\"\xf3\x01\n\x0bRuleBuilder\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07metrics\x18\x03 \x03(\t\x12\'\n\toperators\x18\x04 \x03(\x0b\x32\x14.lmao.RuleBuilder.Op\x12\'\n\tfunctions\x18\x05 \x03(\x0b\x32\x14.lmao.RuleBuilder.Fn\x1a\"\n\x02Op\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x33\n\x02\x46n\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65_meta\x18\x03 \x01(\t2\xeb\n\n\x04LMAO\x12-\n\x08init_run\x12\x14.lmao.InitRunRequest\x1a\t.lmao.Run\"\x00\x12\x33\n\x11update_run_status\x12\t.lmao.Run\x1a\x11.lmao.Acknowledge\"\x00\x12+\n\x06on_log\x12\x0c.lmao.RunLog\x1a\x11.lmao.Acknowledge\"\x00\x12.\n\x07on_save\x12\x0e.lmao.FileList\x1a\x11.lmao.Acknowledge\"\x00\x12.\n\x0con_train_end\x12\t.lmao.Run\x1a\x11.lmao.Acknowledge\"\x00\x12H\n\rlist_projects\x12\x19.lmao.ListProjectsRequest\x1a\x1a.lmao.ListProjectsResponse\"\x00\x12<\n\tlist_runs\x12\x15.lmao.ListRunsRequest\x1a\x16.lmao.ListRunsResponse\"\x00\x12P\n\x14get_experiment_table\x12\x1f.lmao.GetExperimentTableRequest\x1a\x15.lmao.ExperimentTable\"\x00\x12)\n\x0fget_run_details\x12\t.lmao.Run\x1a\t.lmao.Run\"\x00\x12\x32\n\x0bget_run_log\x12\x13.lmao.RunLogRequest\x1a\x0c.lmao.RunLog\"\x00\x12)\n\nlist_files\x12\t.lmao.Run\x1a\x0e.lmao.FileList\"\x00\x12\x33\n\x11\x64\x65lete_experiment\x12\t.lmao.Run\x1a\x11.lmao.Acknowledge\"\x00\x12\x34\n\x0e\x64\x65lete_project\x12\r.lmao.Project\x1a\x11.lmao.Acknowledge\"\x00\x12\x35\n\x0cinit_serving\x12\x14.lmao.InitRunRequest\x1a\r.lmao.Serving\"\x00\x12\x36\n\x0eon_serving_log\x12\x0f.lmao.LogBuffer\x1a\x11.lmao.Acknowledge\"\x00\x12\x34\n\x0eon_serving_end\x12\r.lmao.Serving\x1a\x11.lmao.Acknowledge\"\x00\x12Q\n\x10list_deployments\x12\x1c.lmao.ListDeploymentsRequest\x1a\x1d.lmao.ListDeploymentsResponse\"\x00\x12H\n\rlist_servings\x12\x19.lmao.ListServingsRequest\x1a\x1a.lmao.ListServingsResponse\"\x00\x12\x35\n\x13get_serving_details\x12\r.lmao.Serving\x1a\r.lmao.Serving\"\x00\x12\x33\n\x0fget_serving_log\x12\r.lmao.Serving\x1a\x0f.lmao.LogBuffer\"\x00\x12\'\n\x0b\x63reate_rule\x12\n.lmao.Rule\x1a\n.lmao.Rule\"\x00\x12\x30\n\nlist_rules\x12\x0f.lmao.ListRules\x1a\x0f.lmao.ListRules\"\x00\x12.\n\x0b\x64\x65lete_rule\x12\n.lmao.Rule\x1a\x11.lmao.Acknowledge\"\x00\x12.\n\x0bupdate_rule\x12\n.lmao.Rule\x1a\x11.lmao.Acknowledge\"\x00\x12:\n\x10get_rule_builder\x12\x11.lmao.RuleBuilder\x1a\x11.lmao.RuleBuilder\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lmao_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGBUFFER._serialized_start=53
  _LOGBUFFER._serialized_end=158
  _SERVINGHTTPLOG._serialized_start=161
  _SERVINGHTTPLOG._serialized_end=295
  _LISTDEPLOYMENTSREQUEST._serialized_start=297
  _LISTDEPLOYMENTSREQUEST._serialized_end=388
  _LISTDEPLOYMENTSRESPONSE._serialized_start=391
  _LISTDEPLOYMENTSRESPONSE._serialized_end=590
  _LISTDEPLOYMENTSRESPONSE_SERVING._serialized_start=517
  _LISTDEPLOYMENTSRESPONSE_SERVING._serialized_end=590
  _LISTSERVINGSREQUEST._serialized_start=592
  _LISTSERVINGSREQUEST._serialized_end=705
  _LISTSERVINGSRESPONSE._serialized_start=707
  _LISTSERVINGSRESPONSE._serialized_end=803
  _SERVING._serialized_start=806
  _SERVING._serialized_end=1038
  _SERVING_STATUS._serialized_start=989
  _SERVING_STATUS._serialized_end=1038
  _RECORD._serialized_start=1041
  _RECORD._serialized_end=1230
  _RECORD_DATATYPE._serialized_start=1184
  _RECORD_DATATYPE._serialized_end=1230
  _RECORDCOLUMN._serialized_start=1233
  _RECORDCOLUMN._serialized_end=1488
  _RECORDCOLUMN_RECORDROW._serialized_start=1355
  _RECORDCOLUMN_RECORDROW._serialized_end=1440
  _RECORDCOLUMN_DATATYPE._serialized_start=1184
  _RECORDCOLUMN_DATATYPE._serialized_end=1230
  _RUNLOG._serialized_start=1491
  _RUNLOG._serialized_end=1715
  _RUNLOG_LOGTYPE._serialized_start=1675
  _RUNLOG_LOGTYPE._serialized_end=1715
  _AGENTDETAILS._serialized_start=1718
  _AGENTDETAILS._serialized_end=1933
  _AGENTDETAILS_NBX._serialized_start=1888
  _AGENTDETAILS_NBX._serialized_end=1915
  _INITRUNREQUEST._serialized_start=1936
  _INITRUNREQUEST._serialized_end=2075
  _FILE._serialized_start=2077
  _FILE._serialized_end=2154
  _FILELIST._serialized_start=2156
  _FILELIST._serialized_end=2216
  _RUN._serialized_start=2219
  _RUN._serialized_end=2609
  _RUN_STATUS._serialized_start=2535
  _RUN_STATUS._serialized_end=2609
  _LISTPROJECTSREQUEST._serialized_start=2611
  _LISTPROJECTSREQUEST._serialized_end=2699
  _PROJECT._serialized_start=2702
  _PROJECT._serialized_end=2880
  _LISTPROJECTSRESPONSE._serialized_start=2882
  _LISTPROJECTSRESPONSE._serialized_end=2958
  _LISTRUNSREQUEST._serialized_start=2960
  _LISTRUNSREQUEST._serialized_end=3073
  _LISTRUNSRESPONSE._serialized_start=3075
  _LISTRUNSRESPONSE._serialized_end=3172
  _RUNLOGREQUEST._serialized_start=3174
  _RUNLOGREQUEST._serialized_end=3301
  _ACKNOWLEDGE._serialized_start=3303
  _ACKNOWLEDGE._serialized_end=3350
  _GETEXPERIMENTTABLEREQUEST._serialized_start=3353
  _GETEXPERIMENTTABLEREQUEST._serialized_end=3490
  _EXPERIMENTTABLE._serialized_start=3493
  _EXPERIMENTTABLE._serialized_end=3636
  _EXPERIMENTTABLE_ROW._serialized_start=3574
  _EXPERIMENTTABLE_ROW._serialized_end=3636
  _RULE._serialized_start=3639
  _RULE._serialized_end=3910
  _LISTRULES._serialized_start=3913
  _LISTRULES._serialized_end=4050
  _RULEBUILDER._serialized_start=4053
  _RULEBUILDER._serialized_end=4296
  _RULEBUILDER_OP._serialized_start=4209
  _RULEBUILDER_OP._serialized_end=4243
  _RULEBUILDER_FN._serialized_start=4245
  _RULEBUILDER_FN._serialized_end=4296
  _LMAO._serialized_start=4299
  _LMAO._serialized_end=5686
# @@protoc_insertion_point(module_scope)
